var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as listener from './wsListener';
import { authDataProvider } from './auth';
import * as orderService from './orderService';
import * as orderStore from './orderStore';
require('dotenv').config();
function init() {
    return __awaiter(this, void 0, void 0, function* () {
        // listener is responsible for receiving orders from Ordering Stack
        const ctx = {
            TENANT: process.env.TENANT,
            VENUE: process.env.VENUE,
            BASE_URL: process.env.BASE_URL,
        };
        let refreshToken = '';
        const refreshTokenHandler = {
            getRefreshToken: () => refreshToken,
            setRefreshToken: (_refreshToken) => {
                refreshToken = _refreshToken;
            },
        };
        const params = {
            baseURL: '',
            tenant: ctx.TENANT,
            venue: ctx.VENUE,
            authDataProvider: authDataProvider,
            refreshTokenHandler,
            onConnectedAsync: (accessToken) => __awaiter(this, void 0, void 0, function* () {
                console.log('ws connected!');
                const orders = yield orderService.pullOrders(ctx, ctx.VENUE, accessToken);
                for (const order of orders) {
                    orderStore.onOrderUpdate(order);
                }
            }),
            onDisconnectAsync: () => __awaiter(this, void 0, void 0, function* () {
                console.log('ws disconnected');
            }),
            onKDSMessageAsync: (message) => __awaiter(this, void 0, void 0, function* () {
                console.log(`MESSAGE  order [${message.id}]`);
                orderStore.onOrderUpdate(message);
            }),
            onOrdersUpdateAsync: (order) => __awaiter(this, void 0, void 0, function* () {
                console.log(`new or updated order [${order.id}]`);
                orderStore.onOrderUpdate(order);
            }),
            onNotificationAsync: (message) => __awaiter(this, void 0, void 0, function* () {
                orderStore.onOrderError(message);
                console.log(`NOTIFICATION: ${JSON.stringify(message)}`);
            }),
            onAuthFailure: () => __awaiter(this, void 0, void 0, function* () {
                console.log('------------- MANUAL AUTH REQUIRED ----------------- ');
            }),
        };
        listener.connectWebSockets(params);
    });
}
module.exports = {
    listener,
    orderStore,
};
